==> traffic-0.7.0dev.tar.gz: traffic-0.7.0dev/traffic/release/xdistutils.py <==
##
# .release.distutils - distutils data
##
"""
Python distutils data provisions module.

For sub-packagers, the `prefixed_packages` and `prefixed_extensions` functions
should be of particular interest.
"""
import sys
import os
from .. import project
from . import pypi

subpackages = [
	'test',
	'documentation',
	'release',
]

extensions_data = {
	'lib' : {
		'sources' : [os.path.join('lib.py.c')],
	},
}

# linux support
if sys.platform.startswith('linux'):
	# XXX: Maybe use pkg-config in the future.
	# The configure;make;make install performed on fc16
	# doesn't have a working kqueue.pc, so hard
	# coding this seems like the best alternative.
	kqprefix = os.environ.get('KQUEUE_PREFIX', '/usr')
	# assume libkqueue
	extensions_data['lib']['libraries'] = [
		'kqueue',
	]
	extensions_data['lib']['include_dirs'] = [
		os.path.join(kqprefix, 'include/kqueue'),
	]
	extensions_data['lib']['library_dirs'] = [
		os.path.join(kqprefix, 'lib'),
	]

package_data = {
	'documentation' : ['*.txt'],
	None : ['*.c'],
}

try:
	# :)
	if __package__ is not None:
		default_prefix = __package__.split('.')[:-1]
	else:
		default_prefix = __name__.split('.')[:-2]
except NameError:
	default_prefix = ['traffic']

def prefixed_extensions(
	prefix = default_prefix,
	extensions_data = extensions_data,
):
	"""
	Generator producing the `distutils` `Extension` objects.
	"""
	pkg_prefix = '.'.join(prefix) + '.'
	path_prefix = os.path.sep.join(prefix)
	for mod, data in extensions_data.items():
		yield (
			pkg_prefix + mod,
			dict(
				sources = [os.path.join(path_prefix, src) for src in data['sources']],
				libraries = data.get('libraries', []),
			),
		)

def prefixed_packages(
	prefix = default_prefix,
	packages = subpackages,
):
	"""
	Generator producing the standard `package` list prefixed with `prefix`.
	"""
	prefix = '.'.join(prefix)
	yield prefix
	prefix = prefix + '.'
	for pkg in packages:
		yield prefix + pkg

def prefixed_package_data(
	prefix = default_prefix,
	package_data = package_data,
):
	"""
	Generator producing the standard `package` list prefixed with `prefix`.
	"""
	prefix = '.'.join(prefix)
	for pkg, data in package_data.items():
		if pkg is None:
			yield prefix, data
		else:
			yield prefix + '.' + pkg, data

def standard_setup_keywords(build_extensions = True, prefix = default_prefix):
	return {
		'name' : project.name,
		'version' : project.version,
		'description' : project.description,
		'author' : 'James William Pye',
		'author_email' : 'x@jwp.io',
		'maintainer' : 'James William Pye',
		'maintainer_email' : 'py-traffic@googlegroups.com',
		'long_description' : pypi.LONG_DESCRIPTION,
		'url' : pypi.URL,
		'classifiers' : pypi.CLASSIFIERS,
		'packages' : list(prefixed_packages(prefix = prefix)),
		'package_data' : dict(prefixed_package_data(prefix = prefix)),
		'ext_modules' : list(prefixed_extensions(prefix = prefix)),
	}

==> traffic-0.8.1dev.tar.gz: traffic-0.8.1dev/traffic/release/xdistutils.py <==
##
# .release.xdistutils - distutils data
##
"""
Python distutils data provisions module.

For sub-packagers, the `prefixed_packages` and `prefixed_extensions`
functions should be of particular interest.
"""
import sys
import os
from .. import project
from . import pypi

subpackages = [
	'test',
	'documentation',
	'release',
]

extensions_data = {
	'lib' : {
		'sources' : [
			os.path.join('libkqueue.py.c'),
			#os.path.join('libnetmap.py.c'),
		],
	},
}

# linux support
if sys.platform.startswith('linux'):
	# XXX: Maybe use pkg-config in the future.
	# The configure;make;make install performed on fc16
	# doesn't have a working kqueue.pc, so hard
	# coding this seems like the best alternative.
	kqprefix = os.environ.get('KQUEUE_PREFIX', '/usr')
	# assume libkqueue
	extensions_data['lib']['libraries'] = [
		'kqueue',
	]
	extensions_data['lib']['include_dirs'] = [
		os.path.join(kqprefix, 'include/kqueue'),
	]
	extensions_data['lib']['library_dirs'] = [
		os.path.join(kqprefix, 'lib'),
	]

package_data = {
	'documentation' : ['*.txt'],
	None : ['*.c'],
}

try:
	# :)
	if __package__ is not None:
		default_prefix = __package__.split('.')[:-1]
	else:
		default_prefix = __name__.split('.')[:-2]
except NameError:
	default_prefix = ['traffic']

def prefixed_extensions(
	prefix = default_prefix,
	extensions_data = extensions_data,
):
	"""
	Generator producing the `distutils` `Extension` objects.
	"""
	pkg_prefix = '.'.join(prefix) + '.'
	path_prefix = os.path.sep.join(prefix)
	for mod, data in extensions_data.items():
		yield (
			pkg_prefix + mod,
			dict(
				sources = [os.path.join(path_prefix, src) for src in data['sources']],
				libraries = data.get('libraries', []),
			),
		)

def prefixed_packages(
	prefix = default_prefix,
	packages = subpackages,
):
	"""
	Generator producing the standard `package` list prefixed with `prefix`.
	"""
	prefix = '.'.join(prefix)
	yield prefix
	prefix = prefix + '.'
	for pkg in packages:
		yield prefix + pkg

def prefixed_package_data(
	prefix = default_prefix,
	package_data = package_data,
):
	"""
	Generator producing the standard `package` list prefixed with `prefix`.
	"""
	prefix = '.'.join(prefix)
	for pkg, data in package_data.items():
		if pkg is None:
			yield prefix, data
		else:
			yield prefix + '.' + pkg, data

def standard_setup_keywords(build_extensions = True, prefix = default_prefix):
	return {
		'name' : project.name,
		'version' : project.version,
		'description' : project.description,
		'author' : project.meaculpa,
		'author_email' : project.contact,
		'long_description' : pypi.LONG_DESCRIPTION,
		'url' : pypi.URL,
		'classifiers' : pypi.CLASSIFIERS,
		'packages' : list(prefixed_packages(prefix = prefix)),
		'package_data' : dict(prefixed_package_data(prefix = prefix)),
		'ext_modules' : list(prefixed_extensions(prefix = prefix)),
	}
